#ifndef KYSEC_PBLK_LIST_H
#define KYSEC_PBLK_LIST_H

enum {
	KYLIN_PBLK_DISABLE = 0,	/* 关闭 */
	KYLIN_PBLK_ENABLE	/* 开启 */
};

#ifdef __cplusplus
extern "C" {
#endif

/*
 * 设置程序黑名单状态
 * 参数： KYLIN_PBLK_DISABLE 关闭； KYLIN_PBLK_ENABLE 开启
 * 返回值:
 * 		0 : 设置成功
 * 		1 : 当前状态设置成功，但重启后状态会恢复默认状态
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-3 : 程序黑名单设置失败
 */
int kylin_pblk_status_set(int status);

/*
 * 获取当前程序管控状态
 * 参数：
 * 返回值:
 * 		0 : 关闭
 * 		1 : 开启
 * 		其他 : 获取失败
 */
int kylin_pblk_status_get(void);

/*
 * 添加应用至管控名单
 * 参数：path	应用程序绝对路径
 *
 * 返回值:
 * 		0 : 添加成功
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-4 : 添加至管控列表失败
 * 		-5 : 获取应用基准值失败
 * 		-6 : 设置应用进程保护状态失败
 */
int kylin_pblk_list_add(const char *path);

/*
 * 添加应用至管控名单
 * 参数：path	应用程序绝对路径
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值:
 * 		0 : 添加成功
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-3 : 添加至管控列表失败
 * 		-4 : 获取应用基准值失败
 * 		-5 : 设置应用进程保护状态失败
 */
int kylin_pblk_list_add_kdk(const char *path, int data_source_type, char *data_source_name);

/*
 * 从管控名单中删除应用
 * 参数：path	应用程序绝对路径
 * 返回值:
 * 		0 : 删除成功
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-3 : 从管控列表删除失败
 * 		-4 : 获取应用基准值失败
 * 		-5 : 移除应用进程保护状态失败
 */
int kylin_pblk_list_del(const char *path);

/*
 * 从管控名单中删除应用
 * 参数：path	应用程序绝对路径
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值:
 * 		0 : 删除成功
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-3 : 从管控列表删除失败
 * 		-4 : 获取应用基准值失败
 * 		-5 : 移除应用进程保护状态失败
 */
int kylin_pblk_list_del_kdk(const char *path, int data_source_type, char *data_source_name);


/*
 * kdk: 清空策略
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值：0:成功，非0:失败
 */
int kylin_pblk_clear_policy_kdk(const int data_source_type, char *data_source_name);

/*
 * 获取进程保护列表数据
 * 参数：count	返回list大小
 * 返回值:
 * 		NULL : 获取失败或列表为空
 * 		非NULL : list列表，大小为count大小
 */
char **kylin_pblk_list_get(int *count);



#ifdef __cplusplus
}
#endif

#endif // KYSEC_PBLK_LIST_H
